diff --git a/core/COPYRIGHT.txt b/core/COPYRIGHT.txt
index 7db40ad2811b1ea951a6d85b86a5f7809cd3bd7e..6c6d0ad34e7f032de4a09e2b43d37249cba87636 100644
--- a/core/COPYRIGHT.txt
+++ b/core/COPYRIGHT.txt
@@ -20,7 +20,7 @@ Drupal includes works under other copyright notices and distributed
 according to the terms of the GNU General Public License or a compatible
 license, including:
 
-Javascript
+JavaScript
 
   Farbtastic - Copyright (c) 2010 Matt Farina
 
diff --git a/core/misc/entity-form.es6.js b/core/misc/entity-form.es6.js
index 6ccae70bcb29eef13719fa0f349e7966414c0162..7dc6f7ecc7d926965659a0fdd20309018efce617 100644
--- a/core/misc/entity-form.es6.js
+++ b/core/misc/entity-form.es6.js
@@ -1,6 +1,6 @@
 /**
  * @file
- * Defines Javascript behaviors for the block_content module.
+ * Defines JavaScript behaviors for the block_content module.
  */
 
 (function($, Drupal) {
diff --git a/core/modules/action/tests/src/FunctionalJavascript/ActionFormAjaxTest.php b/core/modules/action/tests/src/FunctionalJavascript/ActionFormAjaxTest.php
index 3f62c287644c8d5e921a071ecc1b003e01e1932d..d691a1975cc110b04e4dfd582b5c59a55365c6f8 100644
--- a/core/modules/action/tests/src/FunctionalJavascript/ActionFormAjaxTest.php
+++ b/core/modules/action/tests/src/FunctionalJavascript/ActionFormAjaxTest.php
@@ -7,7 +7,7 @@
 use Drupal\system\Entity\Action;
 
 /**
- * Tests action plugins using Javascript.
+ * Tests action plugins using JavaScript.
  *
  * @group action
  */
diff --git a/core/modules/book/book.es6.js b/core/modules/book/book.es6.js
index deb518ba9b3ab5050bfb7650ec82f664860ceab0..ed611b56830e6f9515d618acef67f2940462d201 100644
--- a/core/modules/book/book.es6.js
+++ b/core/modules/book/book.es6.js
@@ -1,6 +1,6 @@
 /**
  * @file
- * Javascript behaviors for the Book module.
+ * JavaScript behaviors for the Book module.
  */
 
 (function($, Drupal) {
diff --git a/core/modules/book/book.module b/core/modules/book/book.module
index 8bb1bb38a5ac14194d5c73a290a82a14c6ee9dfb..0a6a56555a453d02d07e80bf805b95266bf49f38 100644
--- a/core/modules/book/book.module
+++ b/core/modules/book/book.module
@@ -148,7 +148,7 @@ function book_form_node_form_alter(&$form, FormStateInterface $form_state, $form
   if ($access) {
     $collapsed = !($node->isNew() && !empty($node->book['pid']));
     $form = \Drupal::service('book.manager')->addFormElements($form, $form_state, $node, $account, $collapsed);
-    // The "js-hide" class hides submit button when Javascript is enabled.
+    // The "js-hide" class hides submit button when JavaScript is enabled.
     $form['book']['pick-book'] = [
       '#type' => 'submit',
       '#value' => t('Change book (update list of parents)'),
diff --git a/core/modules/content_translation/src/FieldTranslationSynchronizer.php b/core/modules/content_translation/src/FieldTranslationSynchronizer.php
index 21551f000ec9d2cea23c706c6741def7a6d7a6a8..4c4aaaf93bf25345377d41833acb38ef3dd6a76b 100644
--- a/core/modules/content_translation/src/FieldTranslationSynchronizer.php
+++ b/core/modules/content_translation/src/FieldTranslationSynchronizer.php
@@ -142,7 +142,7 @@ public function synchronizeFields(ContentEntityInterface $entity, $sync_langcode
 
         // If a group was selected has the require_all_groups_for_translation
         // flag set, there are no untranslatable columns. This is done because
-        // the UI adds Javascript that disables the other checkboxes, so their
+        // the UI adds JavaScript that disables the other checkboxes, so their
         // values are not saved.
         foreach (array_filter($translation_sync) as $group) {
           if (!empty($column_groups[$group]['require_all_groups_for_translation'])) {
diff --git a/core/modules/media/js/form.es6.js b/core/modules/media/js/form.es6.js
index e8ebb8d728204f3abedb771543712786bc77be54..e3fb01ebd747c5b045c227cc945694a35711acb3 100644
--- a/core/modules/media/js/form.es6.js
+++ b/core/modules/media/js/form.es6.js
@@ -1,6 +1,6 @@
 /**
  * @file
- * Defines Javascript behaviors for the media form.
+ * Defines JavaScript behaviors for the media form.
  */
 
 (function($, Drupal) {
diff --git a/core/modules/node/content_types.es6.js b/core/modules/node/content_types.es6.js
index 01f97bbaa2568f5ab0115b8601e281d930b44ffb..9a22e141ca1d91cd141d76257728ab943b01d4f5 100644
--- a/core/modules/node/content_types.es6.js
+++ b/core/modules/node/content_types.es6.js
@@ -1,6 +1,6 @@
 /**
  * @file
- * Javascript for the node content editing form.
+ * JavaScript for the node content editing form.
  */
 
 (function($, Drupal) {
diff --git a/core/modules/node/node.es6.js b/core/modules/node/node.es6.js
index 95f183a3ad8bfcbe6704094ef0f5bc65fceecf30..06229fcb335d5cde30e2d8dc65c827ed95fe0137 100644
--- a/core/modules/node/node.es6.js
+++ b/core/modules/node/node.es6.js
@@ -1,6 +1,6 @@
 /**
  * @file
- * Defines Javascript behaviors for the node module.
+ * Defines JavaScript behaviors for the node module.
  */
 
 (function($, Drupal, drupalSettings) {
diff --git a/core/modules/settings_tray/settings_tray.module b/core/modules/settings_tray/settings_tray.module
index 9415ffdb8ff37b849de05468a79e5957e8be9553..4ef7187a5c9ada19ad09431b2148ca58dc74287b 100644
--- a/core/modules/settings_tray/settings_tray.module
+++ b/core/modules/settings_tray/settings_tray.module
@@ -120,7 +120,7 @@ function settings_tray_preprocess_block(&$variables) {
   if (isset($variables['elements']['#contextual_links']['block']['route_parameters']['block'])) {
     $block = Block::load($variables['elements']['#contextual_links']['block']['route_parameters']['block']);
     if ($access_checker->accessBlockPlugin($block_plugin)->isAllowed() && !_settings_tray_has_block_overrides($block)) {
-      // Add class and attributes to all blocks to allow Javascript to target.
+      // Add class and attributes to all blocks to allow JavaScript to target.
       $variables['attributes']['class'][] = 'settings-tray-editable';
       $variables['attributes']['data-drupal-settingstray'] = 'editable';
     }
diff --git a/core/modules/system/css/components/js.module.css b/core/modules/system/css/components/js.module.css
index ca3c739b3a3d4581a598b13640d3cde580909db7..68f1ee54dffc598f47018058f9ba8ac86ff0e5a8 100644
--- a/core/modules/system/css/components/js.module.css
+++ b/core/modules/system/css/components/js.module.css
@@ -1,6 +1,6 @@
 /**
  * @file
- * Utility classes to assist with Javascript functionality.
+ * Utility classes to assist with JavaScript functionality.
  */
 
 /**
diff --git a/core/modules/system/tests/modules/js_message_test/src/Controller/JSMessageTestController.php b/core/modules/system/tests/modules/js_message_test/src/Controller/JSMessageTestController.php
index c83aae77cf4f08ba5b52195d634ec2e3e14487de..b637833771aaa387cfecab627dea89785cac7580 100644
--- a/core/modules/system/tests/modules/js_message_test/src/Controller/JSMessageTestController.php
+++ b/core/modules/system/tests/modules/js_message_test/src/Controller/JSMessageTestController.php
@@ -30,7 +30,7 @@ public static function getMessagesSelectors() {
   }
 
   /**
-   * Displays links to show messages via Javascript.
+   * Displays links to show messages via JavaScript.
    *
    * @return array
    *   Render array for links.
diff --git a/core/modules/system/tests/src/Functional/Routing/DestinationTest.php b/core/modules/system/tests/src/Functional/Routing/DestinationTest.php
index ba10d839b230f376a9aec182e0d450526231ab4b..94d74d100352945fb61cd13aa221bf80423479c0 100644
--- a/core/modules/system/tests/src/Functional/Routing/DestinationTest.php
+++ b/core/modules/system/tests/src/Functional/Routing/DestinationTest.php
@@ -63,7 +63,7 @@ public function testDestination() {
       [
         'input' => 'javascript:alert(0)',
         'output' => 'javascript:alert(0)',
-        'message' => 'Javascript URL is allowed because it is treated as an internal URL.',
+        'message' => 'JavaScript URL is allowed because it is treated as an internal URL.',
       ],
     ];
     foreach ($test_cases as $test_case) {
diff --git a/core/modules/views/config/schema/views.style.schema.yml b/core/modules/views/config/schema/views.style.schema.yml
index 49de11b4097df8e747d1fb44b5c34c2a3d6d8284..f31f67ac437bfa8d561962d6a298ab1328be0d2b 100644
--- a/core/modules/views/config/schema/views.style.schema.yml
+++ b/core/modules/views/config/schema/views.style.schema.yml
@@ -91,7 +91,7 @@ views.style.table:
       label: 'Override normal sorting if click sorting is used'
     sticky:
       type: boolean
-      label: 'Enable Drupal style "sticky" table headers (Javascript)'
+      label: 'Enable Drupal style "sticky" table headers (JavaScript)'
     summary:
       type: label
       label: 'Summary title'
diff --git a/core/modules/views/js/ajax_view.es6.js b/core/modules/views/js/ajax_view.es6.js
index cbcec78ffc68730d464c5ac90237b04bc8a54b3a..e131ad83b84c2e80b4e429d3616d04d2eab14f89 100644
--- a/core/modules/views/js/ajax_view.es6.js
+++ b/core/modules/views/js/ajax_view.es6.js
@@ -51,7 +51,7 @@
   Drupal.views.instances = {};
 
   /**
-   * Javascript object for a certain view.
+   * JavaScript object for a certain view.
    *
    * @constructor
    *
diff --git a/core/modules/views/src/Plugin/views/style/Table.php b/core/modules/views/src/Plugin/views/style/Table.php
index 0058bdc4f059296ee671e3287d5ef694fc85adfe..0673642a989d2a1b006684a2409316287384e324 100644
--- a/core/modules/views/src/Plugin/views/style/Table.php
+++ b/core/modules/views/src/Plugin/views/style/Table.php
@@ -215,7 +215,7 @@ public function buildOptionsForm(&$form, FormStateInterface $form_state) {
 
     $form['sticky'] = [
       '#type' => 'checkbox',
-      '#title' => $this->t('Enable Drupal style "sticky" table headers (Javascript)'),
+      '#title' => $this->t('Enable Drupal style "sticky" table headers (JavaScript)'),
       '#default_value' => !empty($this->options['sticky']),
       '#description' => $this->t('(Sticky header effects will not be active for preview below, only on live output.)'),
     ];
diff --git a/core/modules/views/templates/views-view.html.twig b/core/modules/views/templates/views-view.html.twig
index 8c4201fccfbdd17e83f82e2cf9d842edfe5d2855..b78c12c5ef0450f0518a183d1331da029e4fe779 100644
--- a/core/modules/views/templates/views-view.html.twig
+++ b/core/modules/views/templates/views-view.html.twig
@@ -25,7 +25,7 @@
  * - attachment_after: An optional attachment view to be displayed after the
  *   view content.
  * - dom_id: Unique id for every view being printed to give unique class for
- *   Javascript.
+ *   JavaScript.
  *
  * @see template_preprocess_views_view()
  *
diff --git a/core/modules/views_ui/admin.inc b/core/modules/views_ui/admin.inc
index 63c61902c48fab1db607526da275cae370fbf040..a37ea0e11ca50b01a6f3a6e487d1fc3af7e6e69d 100644
--- a/core/modules/views_ui/admin.inc
+++ b/core/modules/views_ui/admin.inc
@@ -193,7 +193,7 @@ function views_ui_ajax_update_form($form, FormStateInterface $form_state) {
 }
 
 /**
- * Non-Javascript fallback for updating the add view form.
+ * Non-JavaScript fallback for updating the add view form.
  */
 function views_ui_nojs_submit($form, FormStateInterface $form_state) {
   $form_state->setRebuild();
diff --git a/core/profiles/demo_umami/themes/umami/templates/classy/views/views-view.html.twig b/core/profiles/demo_umami/themes/umami/templates/classy/views/views-view.html.twig
index 769a86849e885e5795ab0da396f366556770b23a..251b0611dda6860b969faadcdbc08c9a84dfe8d8 100644
--- a/core/profiles/demo_umami/themes/umami/templates/classy/views/views-view.html.twig
+++ b/core/profiles/demo_umami/themes/umami/templates/classy/views/views-view.html.twig
@@ -25,7 +25,7 @@
  * - attachment_after: An optional attachment view to be displayed after the
  *   view content.
  * - dom_id: Unique id for every view being printed to give unique class for
- *   Javascript.
+ *   JavaScript.
  *
  * @see template_preprocess_views_view()
  */
diff --git a/core/tests/Drupal/FunctionalJavascriptTests/Dialog/DialogPositionTest.php b/core/tests/Drupal/FunctionalJavascriptTests/Dialog/DialogPositionTest.php
index bf1f44bc1aaeccdeb35ba2ed6950e79ed4ab3b1c..c4e64abfa1b7631913ea236f123311d16574b16c 100644
--- a/core/tests/Drupal/FunctionalJavascriptTests/Dialog/DialogPositionTest.php
+++ b/core/tests/Drupal/FunctionalJavascriptTests/Dialog/DialogPositionTest.php
@@ -47,7 +47,7 @@ public function testDialogOpenAndClose() {
     $dialog = $page->find('css', '.ui-dialog');
     $this->assertNull($dialog, 'Dialog is closed after clicking the close button.');
 
-    // Resize the window. The test should pass after waiting for Javascript to
+    // Resize the window. The test should pass after waiting for JavaScript to
     // finish as no Javascript errors should have been triggered. If there were
     // javascript errors the test will fail on that.
     $session->resizeWindow(625, 625);
diff --git a/core/tests/Drupal/FunctionalJavascriptTests/JSWebAssert.php b/core/tests/Drupal/FunctionalJavascriptTests/JSWebAssert.php
index 6cf3ef0066712c11d4a29c617ac575366eee3002..a95d33158ddcc6a58f8901b15928c9cc5ac806ff 100644
--- a/core/tests/Drupal/FunctionalJavascriptTests/JSWebAssert.php
+++ b/core/tests/Drupal/FunctionalJavascriptTests/JSWebAssert.php
@@ -222,7 +222,7 @@ public function waitOnAutocomplete() {
    * Test that a node, or its specific corner, is visible in the viewport.
    *
    * Note: Always set the viewport size. This can be done in your test with
-   * \Behat\Mink\Session->resizeWindow(). Drupal CI Javascript tests by default
+   * \Behat\Mink\Session->resizeWindow(). Drupal CI JavaScript tests by default
    * use a viewport of 1024x768px.
    *
    * @param string $selector_type
@@ -319,7 +319,7 @@ public function assertNotVisibleInViewport($selector_type, $selector, $corner =
   private function checkNodeVisibilityInViewport(NodeElement $node, $corner = FALSE) {
     $xpath = $node->getXpath();
 
-    // Build the Javascript to test if the complete element or a specific corner
+    // Build the JavaScript to test if the complete element or a specific corner
     // is in the viewport.
     switch ($corner) {
       case 'topLeft':
@@ -392,7 +392,7 @@ function t(r, lx, ly) {
         throw new UnsupportedDriverActionException($corner, $this->session->getDriver());
     }
 
-    // Build the full Javascript test. The shared logic gets the corner
+    // Build the full JavaScript test. The shared logic gets the corner
     // specific test logic injected.
     $full_javascript_visibility_test = <<<JS
       (function(t){
@@ -408,7 +408,7 @@ function t(r, lx, ly) {
       }($test_javascript_function));
 JS;
 
-    // Check the visibility by injecting and executing the full Javascript test
+    // Check the visibility by injecting and executing the full JavaScript test
     // script in the page.
     return $this->session->evaluateScript($full_javascript_visibility_test);
   }
diff --git a/core/tests/Drupal/FunctionalJavascriptTests/JavascriptGetDrupalSettingsTest.php b/core/tests/Drupal/FunctionalJavascriptTests/JavascriptGetDrupalSettingsTest.php
index 5cd19cc701f6095516110f0c40c96a3df063b83a..38d4000fcd6b179cd09bfae07bdb4a5ed24a8545 100644
--- a/core/tests/Drupal/FunctionalJavascriptTests/JavascriptGetDrupalSettingsTest.php
+++ b/core/tests/Drupal/FunctionalJavascriptTests/JavascriptGetDrupalSettingsTest.php
@@ -32,7 +32,7 @@ public function testGetDrupalSettings() {
     $js_settings = $this->getDrupalSettings();
     $this->assertSame('azAZ09();.,\\\/-_{}', $js_settings['test-setting']);
 
-    // Dynamically change the setting using Javascript.
+    // Dynamically change the setting using JavaScript.
     $script = <<<EndOfScript
 (function () {
   drupalSettings['test-setting'] = 'foo';
diff --git a/core/tests/Drupal/FunctionalJavascriptTests/WebDriverWebAssert.php b/core/tests/Drupal/FunctionalJavascriptTests/WebDriverWebAssert.php
index e621c1a0725cf82c9c697d1f28ce37cf9342b005..93995f459ee615c3b2320133ebfe7c23182f78d0 100644
--- a/core/tests/Drupal/FunctionalJavascriptTests/WebDriverWebAssert.php
+++ b/core/tests/Drupal/FunctionalJavascriptTests/WebDriverWebAssert.php
@@ -14,7 +14,7 @@ class WebDriverWebAssert extends JSWebAssert {
    *   The status code.
    */
   public function statusCodeEquals($code) {
-    @trigger_error('Support for statusCodeEquals is to be dropped from Javascript tests. See https://www.drupal.org/node/2857562.');
+    @trigger_error('Support for statusCodeEquals is to be dropped from JavaScript tests. See https://www.drupal.org/node/2857562.');
     parent::statusCodeEquals($code);
   }
 
@@ -25,7 +25,7 @@ public function statusCodeEquals($code) {
    *   The status code.
    */
   public function statusCodeNotEquals($code) {
-    @trigger_error('Support for statusCodeNotEquals is to be dropped from Javascript tests. See https://www.drupal.org/node/2857562.');
+    @trigger_error('Support for statusCodeNotEquals is to be dropped from JavaScript tests. See https://www.drupal.org/node/2857562.');
     parent::statusCodeNotEquals($code);
   }
 
@@ -38,7 +38,7 @@ public function statusCodeNotEquals($code) {
    *   The value to check the header against.
    */
   public function responseHeaderEquals($name, $value) {
-    @trigger_error('Support for responseHeaderEquals is to be dropped from Javascript tests. See https://www.drupal.org/node/2857562.');
+    @trigger_error('Support for responseHeaderEquals is to be dropped from JavaScript tests. See https://www.drupal.org/node/2857562.');
     parent::responseHeaderEquals($name, $value);
   }
 
@@ -51,7 +51,7 @@ public function responseHeaderEquals($name, $value) {
    *   The value to check the header against.
    */
   public function responseHeaderNotEquals($name, $value) {
-    @trigger_error('Support for responseHeaderNotEquals is to be dropped from Javascript tests. See https://www.drupal.org/node/2857562.');
+    @trigger_error('Support for responseHeaderNotEquals is to be dropped from JavaScript tests. See https://www.drupal.org/node/2857562.');
     parent::responseHeaderNotEquals($name, $value);
   }
 
@@ -64,7 +64,7 @@ public function responseHeaderNotEquals($name, $value) {
    *   The value to check the header against.
    */
   public function responseHeaderContains($name, $value) {
-    @trigger_error('Support for responseHeaderContains is to be dropped from Javascript tests. See https://www.drupal.org/node/2857562.');
+    @trigger_error('Support for responseHeaderContains is to be dropped from JavaScript tests. See https://www.drupal.org/node/2857562.');
     parent::responseHeaderContains($name, $value);
   }
 
@@ -77,7 +77,7 @@ public function responseHeaderContains($name, $value) {
    *   The value to check the header against.
    */
   public function responseHeaderNotContains($name, $value) {
-    @trigger_error('Support for responseHeaderNotContains is to be dropped from Javascript tests. See https://www.drupal.org/node/2857562.');
+    @trigger_error('Support for responseHeaderNotContains is to be dropped from JavaScript tests. See https://www.drupal.org/node/2857562.');
     parent::responseHeaderNotContains($name, $value);
   }
 
@@ -90,7 +90,7 @@ public function responseHeaderNotContains($name, $value) {
    *   The value to check the header against.
    */
   public function responseHeaderMatches($name, $regex) {
-    @trigger_error('Support for responseHeaderMatches is to be dropped from Javascript tests. See https://www.drupal.org/node/2857562.');
+    @trigger_error('Support for responseHeaderMatches is to be dropped from JavaScript tests. See https://www.drupal.org/node/2857562.');
     parent::responseHeaderMatches($name, $regex);
   }
 
@@ -103,7 +103,7 @@ public function responseHeaderMatches($name, $regex) {
    *   The value to check the header against.
    */
   public function responseHeaderNotMatches($name, $regex) {
-    @trigger_error('Support for responseHeaderNotMatches is to be dropped from Javascript tests. See https://www.drupal.org/node/2857562.');
+    @trigger_error('Support for responseHeaderNotMatches is to be dropped from JavaScript tests. See https://www.drupal.org/node/2857562.');
     parent::responseHeaderNotMatches($name, $regex);
   }
 
diff --git a/core/tests/Drupal/FunctionalTests/AssertLegacyTrait.php b/core/tests/Drupal/FunctionalTests/AssertLegacyTrait.php
index 7810d4f3a3ce02b1516b6fce67a0c3529f67c9c4..3a69f7d85fcf786e887be92b074173787e998657 100644
--- a/core/tests/Drupal/FunctionalTests/AssertLegacyTrait.php
+++ b/core/tests/Drupal/FunctionalTests/AssertLegacyTrait.php
@@ -146,7 +146,7 @@ protected function assertTextHelper($text, $not_exists = TRUE) {
 
     $raw_content = $this->getSession()->getPage()->getContent();
     // Trying to simulate what the user sees, given that it removes all text
-    // inside the head tags, removes inline Javascript, fix all HTML entities,
+    // inside the head tags, removes inline JavaScript, fix all HTML entities,
     // removes dangerous protocols and filtering out all HTML tags, as they are
     // not visible in a normal browser.
     $raw_content = preg_replace('@<head>(.+?)</head>@si', '', $raw_content);
diff --git a/core/tests/Drupal/KernelTests/Core/Theme/ConfirmClassyCopiesTest.php b/core/tests/Drupal/KernelTests/Core/Theme/ConfirmClassyCopiesTest.php
index bd96fc7cef1193107924262cbab27a6e7da75673..6ef6860207db733d13e9010c76ff2109f4f3d418 100644
--- a/core/tests/Drupal/KernelTests/Core/Theme/ConfirmClassyCopiesTest.php
+++ b/core/tests/Drupal/KernelTests/Core/Theme/ConfirmClassyCopiesTest.php
@@ -840,7 +840,7 @@ protected function getClassyHash($type, $file) {
         'views-view-mapping-test.html.twig' => '818431786e1d19df33cecccad98d5a22',
         'views-view-opml.html.twig' => '4ab17668908dcd4af75d35f891f97fff',
         'views-view-summary-unformatted.html.twig' => '76f6e5882aa7fe6bc0440b66e85a0a6c',
-        'views-view.html.twig' => 'd20ba03bc36703828bb7651baa15f28f',
+        'views-view.html.twig' => '6e823aff4c9a83fa2f426510a90e8f7d',
         'views-view-grid.html.twig' => '8f4ea66bf949530d31a79a44f3d87650',
         'views-view-rss.html.twig' => 'f4e49d0d8df01019245c51ff2a4259c2',
         'block--system-branding-block.html.twig' => '558d83af4c06e78f46790e0e18295588',
diff --git a/core/tests/Drupal/Tests/Core/Security/RequestSanitizerTest.php b/core/tests/Drupal/Tests/Core/Security/RequestSanitizerTest.php
index 7aac8f108b559de0ec521f064da30e1ea09c2770..03450142e002bd335a8c68deb6c86cfeea2dd61a 100644
--- a/core/tests/Drupal/Tests/Core/Security/RequestSanitizerTest.php
+++ b/core/tests/Drupal/Tests/Core/Security/RequestSanitizerTest.php
@@ -321,7 +321,7 @@ public function providerTestAcceptableDestinations() {
     $data[] = ['/example.com'];
     // Internal URL using a colon is allowed.
     $data[] = ['example:test'];
-    // Javascript URL is allowed because it is treated as an internal URL.
+    // JavaScript URL is allowed because it is treated as an internal URL.
     $data[] = ['javascript:alert(0)'];
     return $data;
   }
diff --git a/core/themes/bartik/templates/classy/views/views-view.html.twig b/core/themes/bartik/templates/classy/views/views-view.html.twig
index 769a86849e885e5795ab0da396f366556770b23a..251b0611dda6860b969faadcdbc08c9a84dfe8d8 100644
--- a/core/themes/bartik/templates/classy/views/views-view.html.twig
+++ b/core/themes/bartik/templates/classy/views/views-view.html.twig
@@ -25,7 +25,7 @@
  * - attachment_after: An optional attachment view to be displayed after the
  *   view content.
  * - dom_id: Unique id for every view being printed to give unique class for
- *   Javascript.
+ *   JavaScript.
  *
  * @see template_preprocess_views_view()
  */
diff --git a/core/themes/claro/templates/classy/views/views-view.html.twig b/core/themes/claro/templates/classy/views/views-view.html.twig
index 769a86849e885e5795ab0da396f366556770b23a..251b0611dda6860b969faadcdbc08c9a84dfe8d8 100644
--- a/core/themes/claro/templates/classy/views/views-view.html.twig
+++ b/core/themes/claro/templates/classy/views/views-view.html.twig
@@ -25,7 +25,7 @@
  * - attachment_after: An optional attachment view to be displayed after the
  *   view content.
  * - dom_id: Unique id for every view being printed to give unique class for
- *   Javascript.
+ *   JavaScript.
  *
  * @see template_preprocess_views_view()
  */
diff --git a/core/themes/classy/templates/views/views-view.html.twig b/core/themes/classy/templates/views/views-view.html.twig
index 769a86849e885e5795ab0da396f366556770b23a..251b0611dda6860b969faadcdbc08c9a84dfe8d8 100644
--- a/core/themes/classy/templates/views/views-view.html.twig
+++ b/core/themes/classy/templates/views/views-view.html.twig
@@ -25,7 +25,7 @@
  * - attachment_after: An optional attachment view to be displayed after the
  *   view content.
  * - dom_id: Unique id for every view being printed to give unique class for
- *   Javascript.
+ *   JavaScript.
  *
  * @see template_preprocess_views_view()
  */
diff --git a/core/themes/seven/templates/classy/views/views-view.html.twig b/core/themes/seven/templates/classy/views/views-view.html.twig
index 769a86849e885e5795ab0da396f366556770b23a..251b0611dda6860b969faadcdbc08c9a84dfe8d8 100644
--- a/core/themes/seven/templates/classy/views/views-view.html.twig
+++ b/core/themes/seven/templates/classy/views/views-view.html.twig
@@ -25,7 +25,7 @@
  * - attachment_after: An optional attachment view to be displayed after the
  *   view content.
  * - dom_id: Unique id for every view being printed to give unique class for
- *   Javascript.
+ *   JavaScript.
  *
  * @see template_preprocess_views_view()
  */
diff --git a/core/themes/stable/css/system/components/js.module.css b/core/themes/stable/css/system/components/js.module.css
index ca3c739b3a3d4581a598b13640d3cde580909db7..68f1ee54dffc598f47018058f9ba8ac86ff0e5a8 100644
--- a/core/themes/stable/css/system/components/js.module.css
+++ b/core/themes/stable/css/system/components/js.module.css
@@ -1,6 +1,6 @@
 /**
  * @file
- * Utility classes to assist with Javascript functionality.
+ * Utility classes to assist with JavaScript functionality.
  */
 
 /**
diff --git a/core/themes/stable/templates/views/views-view.html.twig b/core/themes/stable/templates/views/views-view.html.twig
index a1dc03a0563ef0b36b486b83494d365d0aa6d522..c30de976fd1ca074862b00af249a818d880a1d44 100644
--- a/core/themes/stable/templates/views/views-view.html.twig
+++ b/core/themes/stable/templates/views/views-view.html.twig
@@ -25,7 +25,7 @@
  * - attachment_after: An optional attachment view to be displayed after the
  *   view content.
  * - dom_id: Unique id for every view being printed to give unique class for
- *   Javascript.
+ *   JavaScript.
  *
  * @see template_preprocess_views_view()
  */
diff --git a/core/tests/Drupal/FunctionalJavascriptTests/WebDriverTestBase.php b/core/tests/Drupal/FunctionalJavascriptTests/WebDriverTestBase.php
index 40b0a46c494eb3a75a667a8887d82d4acc8294dd..1cc119ffd53e94a245eb20deaebe837338ba8108 100644
--- a/core/tests/Drupal/FunctionalJavascriptTests/WebDriverTestBase.php
+++ b/core/tests/Drupal/FunctionalJavascriptTests/WebDriverTestBase.php
@@ -7,7 +7,7 @@
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
 /**
  * Runs a browser test using a driver that supports Javascript.
  *
  * Base class for testing browser interaction implemented in JavaScript.
  *
@@ -129,7 +129,7 @@ protected function getMinkDriverArgs() {
    * @see \Behat\Mink\Driver\DriverInterface::evaluateScript()
    */
   protected function assertJsCondition($condition, $timeout = 10000, $message = '') {
-    $message = $message ?: "Javascript condition met:\n" . $condition;
+    $message = $message ?: "JavaScript condition met:\n" . $condition;
     $result = $this->getSession()->getDriver()->wait($timeout, $condition);
     $this->assertTrue($result, $message);
   }
@@ -7,7 +7,7 @@
 
 /**
- * Runs a browser test using a driver that supports Javascript.
+ * Runs a browser test using a driver that supports JavaScript.
  *
  * Base class for testing browser interaction implemented in JavaScript.